@@ -2,6 +2,7 @@ import asyncio
 import logging
 import os
 import random
+import signal
 import time
 import yaml
 from cryptography.fernet import Fernet
@@ -21,6 +22,23 @@ from .asset import Asset
 from .severity import Severity
 from .config import encrypt, decrypt, get_config
 
+HEADER_FILE = """
+# WARNING: InfraSonar will make `password` and `secret` values unreadable but
+# this must not be regarded as true encryption as the encryption key is
+# publically available.
+#
+# Example configuration for `myprobe` collector:
+#
+#  myprobe:
+#    config:
+#      username: alice
+#      password: "secret password"
+#    assets:
+#      - id: 12345
+#        config:
+#          username: bob
+#          password: "my secret"
+""".lstrip()
 
 AGENTCORE_HOST = os.getenv('AGENTCORE_HOST', '127.0.0.1')
 AGENTCORE_PORT = int(os.getenv('AGENTCORE_PORT', 8750))
@@ -70,12 +88,20 @@ class Probe:
         self._checks: Dict[Tuple[int, int], asyncio.Future] = {}
 
         if not os.path.exists(config_path):
-            logging.error(f"config file not found: {config_path}")
-            exit(0)
+            try:
+                parent = os.path.dirname(config_path)
+                if not os.path.exists(parent):
+                    os.mkdir(parent)
+                with open(self._config_path, 'w') as file:
+                    file.write(HEADER_FILE)
+            except Exception:
+                logging.exception(f"cannot write file: {config_path}")
+                exit(0)
+            logging.warning(f"created a new configuration file: {config_path}")
         try:
             self._read_local_config()
         except Exception:
-            logging.exception(f"config file invalid: {config_path}")
+            logging.exception(f"configuration file invalid: {config_path}")
             exit(0)
 
     def is_connected(self) -> bool:
@@ -84,7 +110,14 @@ class Probe:
     def is_connecting(self) -> bool:
         return self._connecting
 
-    async def start(self):
+    def _stop(self, signame, *args):
+        logging.warning(
+            f'signal \'{signame}\' received, stop {self.name} probe')
+        for task in asyncio.all_tasks():
+            task.cancel()
+        asyncio.get_event_loop().stop()
+
+    async def _start(self):
         initial_step = 2
         step = 2
         max_step = 2 ** 7
@@ -95,7 +128,20 @@ class Probe:
                 step = min(step * 2, max_step)
             else:
                 step = initial_step
-            await asyncio.sleep(step)
+            for _ in range(step):
+                await asyncio.sleep(1)
+
+    def start(self):
+        signal.signal(signal.SIGINT, self._stop)
+        signal.signal(signal.SIGTERM, self._stop)
+
+        try:
+            asyncio.run(self._start())
+        except asyncio.exceptions.CancelledError:
+            pass
+
+        if self._protocol and self._protocol.transport:
+            self._protocol.transport.close()
 
     async def _connect(self):
         conn = asyncio.get_event_loop().create_connection(
@@ -170,11 +216,7 @@ class Probe:
 
             # Re-write the file
             with open(self._config_path, 'w') as file:
-                file.write("""
-# WARNING: InfraSonar will make `password` and `secret` values unreadable but
-# this must not be regarded as true encryption as the encryption key is
-# publically available.
-""".lstrip())
+                file.write(HEADER_FILE)
                 file.write(yaml.dump(config))
 
             # Now decrypt everything so we can use the configuration
